@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
-import os
-import sys
+from twisted.internet.endpoints import serverFromString
 
 try:
     from cStringIO import StringIO as BytesIO
@@ -9,18 +8,15 @@ except ImportError:
     from io import BytesIO
 
 from twisted.application import service
-from twisted.internet.endpoints import serverFromString
 from twisted.internet.protocol import ServerFactory
 from twisted.python.components import registerAdapter
-from twisted.python import log
 from ldaptor.interfaces import IConnectedLDAPEntry
 from ldaptor.protocols.ldap.ldapserver import LDAPServer
-import shutil
-from ldaptor import ldiftree
 from .settings import LDAP_ACCOUNT_SERVER_PORT
-from twisted.internet import reactor
-from framework.utils import signle_process
-from framework.settings import settings
+from framework.utils import single_process
+
+from ldaptor.ldiftree import *
+from .models import ModelTreeEntry, APP_PATH, get_db_path
 
 
 class LDAPServerFactory(ServerFactory):
@@ -36,24 +32,20 @@ class LDAPServerFactory(ServerFactory):
         return proto
 
 
-from .settings import DBPATH
-
-TPL_DBPATH = os.path.join(get_app_path('ldap_account'), 'ldiftree')
-TMPDBPATH = DBPATH
-
-if not os.path.exists(TMPDBPATH):
-    shutil.rmtree(TMPDBPATH, ignore_errors=True)
-    shutil.copytree(DBPATH, TMPDBPATH)
-
-
 def get_db():
-    db = ldiftree.LDIFTreeEntry(TMPDBPATH)
+    #db = LDIFTreeEntry(get_db_path())
+    db = ModelTreeEntry()
     return db
 
 
-@signle_process.SignleProcessDeco()
-def run_ldap_server(port=LDAP_ACCOUNT_SERVER_PORT):
+@single_process.SingleProcessDeco()
+def run_ldap_server(port=LDAP_ACCOUNT_SERVER_PORT, use_ssl=False):
+    os.environ["DJANGO_ALLOW_ASYNC_UNSAFE"] = "true"
+    import sys
+    from twisted.python import log
+    from twisted.internet import ssl, reactor
     log.startLogging(sys.stderr)
+
     # We initialize our tree
 
     # When the LDAP Server protocol wants to manipulate the DIT, it invokes
@@ -71,11 +63,20 @@ def run_ldap_server(port=LDAP_ACCOUNT_SERVER_PORT):
     factory.debug = True
     application = service.Application("ldaptor-server")
     myService = service.IServiceCollection(application)
-    serverEndpointStr = "tcp:{0}".format(port)
-    e = serverFromString(reactor, serverEndpointStr)
-    d = e.listen(factory)
+
+    if use_ssl:
+        print('use ssl')
+        reactor.listenSSL(port, factory,
+                          ssl.DefaultOpenSSLContextFactory(
+                                  os.path.join(APP_PATH, 'keys/server.key'), os.path.join(APP_PATH, 'keys/server.crt')))
+
+    else:
+        serverEndpointStr = "tcp:{0}".format(port)
+        e = serverFromString(reactor, serverEndpointStr)
+        e.listen(factory)
     reactor.run()
 
 
 if __name__ == '__main__':
+
     run_ldap_server()
