@@ -10,14 +10,17 @@
 import logging
 import typing
 from dataclasses import dataclass
+from functools import reduce
 
 from django.db import models
+from django.db.models import Q
 from django.utils.translation import gettext_lazy as _
 
 from framework.models import BaseModel
-from framework.views import Request
 from framework.utils import trace_msg
 from framework.utils.bitmap import BitMap
+from framework.views import Request
+from ..apps import MyadminConfig
 
 
 class AbsResourceBackend(object):
@@ -81,10 +84,10 @@ class StrResourceBackend(AbsResourceBackend):
 
     @classmethod
     def encode_members(cls, member_list):
-        return set(cls.sep.join((str(x) for x in member_list)))
+        return cls.sep.join((str(x) for x in member_list))
 
 
-def get_resource_backend(_str)->AbsResourceBackend:
+def get_resource_backend(_str) -> AbsResourceBackend:
     if not _str or _str[0] == '0':
         return BitMapResourceBackend
     else:
@@ -100,24 +103,61 @@ class ModelResource(object):
     name = ''
     unique_filed_name = 'id'
     alias_lookup = 'alias'
-    model_class = None
+    model_class: BaseModel = None
     template_context = {}
-    template = ''
     default_template = 'myadmin/widgets/resource_checkbox.html'
+    template = default_template
     help_text = ''
     is_inner = False
 
+    def __init__(self):
+        self.model_class = self.__class__.model_class
+
     @property
     def id_field_lookup(self):
         return '%s_%s' % (self.name, self.unique_filed_name)
 
+    def get_q_condition(self, members_list):
+        q = Q(**{'%s__in' % self.unique_filed_name: members_list})
+        return q
+
     def get_resource_queryset(self, user_model):
         """
         获取资源查询
         :param user_model:
         :return:
         """
-        return user_model.get_resource_queryset_from_name(self.name)
+        model_resource_class = self.model_class
+
+        if user_model.is_root:
+            return model_resource_class.objects.all()
+        return self.get_role_resource(user_model.get_roles())
+
+    def get_role_resource(self, roles):
+        """
+        获取角色是所有的资源 ,资源成员 以 x,x,x 方式
+        :param user_model:
+        :return:
+        """
+        model_class = self.model_class
+
+        resource_objs = Resource.objects.filter(role__in=roles, name=self.name)
+        try:
+            if len(resource_objs) == 1:
+                resource_ids = resource_objs[0].members
+            else:
+                resource_ids = reduce(lambda x, y: y | x, resource_objs)
+        except TypeError as e:
+            resource_ids = []
+        q = self.get_q_condition(resource_ids)
+        return model_class.objects.filter(q).distinct()
+
+    def create_resource(self, role_model, members_list):
+        """创建资源"""
+        resource: Resource = role_model.get_resource_model(self.name)
+        resource.members = members_list
+        resource.save()
+        role_model.resource.add(resource)
 
     def get_template_context(self, request: Request):
         """
@@ -128,8 +168,59 @@ class ModelResource(object):
         return {}
 
     def members_handle(self, members):
-        """members 都转为 int """
-        return (int(i) for i in members if i.isdigit())
+        """ """
+        return {int(i) for i in members}
+
+
+
+class RelaRtionModelResource(ModelResource):
+    """关联模型资源,需要在 model 上定义 role = models.ManyToManyField(Role, verbose_name=_('允许访问的角色')) 字段
+    """
+    role_field_name = 'role'
+    related_field = None
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.check_has_role_many_to_many()
+
+    def check_has_role_many_to_many(self):
+        from myadmin.models import Role
+        for field in self.model_class._meta.many_to_many:
+            if field.related_model is Role:
+                self.role_field_name = field.attname
+                self.related_field = field
+                return
+        raise Exception(
+                '''需要在 %s model 上定义 role = models.ManyToManyField(Role, verbose_name=_('允许访问的角色')) 字段''' % self.model_class)
+
+    def get_role_q(self, roles):
+        return Q(**{'%s__in' % self.role_field_name: roles})
+
+    def get_resource_queryset(self, user_model):
+        """
+        获取资源查询,使用 xxx_set 的方式
+        :param user_model:
+        :return:
+        """
+        roles = user_model.get_roles()
+
+        model_resource_class: BaseModel = self.model_class
+        if user_model.is_root:
+            return model_resource_class.objects.all()
+        return self.get_role_resource(roles)
+
+    def get_role_resource(self, roles):
+        return self.model_class.objects.filter(self.get_role_q(roles)).distinct()
+
+    def create_resource(self, role_model, members_list):
+        """关联模型,反向添加角色
+        使用 role_model.xxx_set.set(members_list, clear=True)
+        """
+        if not role_model.id:
+            role_model.save()
+        m2m_field_name = '%s_set' % self.model_class._meta.model_name
+        getattr(role_model, m2m_field_name).set(self.members_handle(members_list))
+
 
 
 class Resource(BaseModel):
@@ -143,7 +234,10 @@ class Resource(BaseModel):
     _members = models.TextField(_('资源对象成员列表'))
     __members_cache = None
 
+    has_all_resosurce_mark = '__all__'
+
     class Meta:
+        app_label = MyadminConfig.name
         unique_together = (
                 ('name', 'role_id'),  # 联合唯一
         )
@@ -166,7 +260,7 @@ class Resource(BaseModel):
         """
         if self.__members_cache is None:
             _members = get_resource_backend(self._members).decode_members(self._members)
-            self.__members_cache = self._resource_map.get(self.name,ModelResource()).members_handle(_members)
+            self.__members_cache = self._resource_map.get(self.name, ModelResource()).members_handle(_members)
         return self.__members_cache
 
     @members.setter
