@@ -120,6 +120,7 @@ Vue ? Vue.directive('select2', {
     inserted: function (el, binding, vnode) {
 
         $(el).on("change", function (e) {
+
             for (var i = 0; i < vnode.data.directives.length; i++) {
                 if (vnode.data.directives[i].name == "model") {
                     var expression = vnode.data.directives[i].expression
@@ -141,12 +142,12 @@ Vue ? Vue.directive('select2', {
     },
 
     update: function (el, binding, vnode) {
-        // for (var i = 0; i < vnode.data.directives.length; i++) {
-        //     if (vnode.data.directives[i].name == "model") {
-        //         $(el).val(vnode.data.directives[i].value).trigger("change");
-        //         break
-        //     }
-        // }
+        for (var i = 0; i < vnode.data.directives.length; i++) {
+            if (vnode.data.directives[i].name == "model") {
+                $(el).val(vnode.data.directives[i].value).trigger("change");
+                break
+            }
+        }
 
     },
     unbind: function (el) {
@@ -585,6 +586,8 @@ $(document).on('focus', '.datetime', function () {
 // daterange  end --
 
 
+
+
 // Wdate
 $(document).on('focus', '.Wdate', function () {
     WdatePicker({
@@ -659,6 +662,38 @@ $(document).on('click', '.ask', function (e) {
 })
 
 
+function makeToolTips(ele, tooltipText, time) {
+
+    var tooltipEle = inputTooltip(ele, tooltipText, time)
+    if (tooltipText) {
+        tooltipEle.css({'color': 'red'})
+    } else {
+        tooltipEle.hide()
+    }
+}
+$(document).on('blur', '.input-number', function () {
+    var tooltipText = ''
+    var $this = $(this)
+    var value = $this.val()
+
+    if (isNaN(value) || value.length == 0) {
+        tooltipText = '输入的不是数字 !'
+        //alert(tooltipText)
+        $this.val(value.replace(/[^\d-\.]+/g, ''))
+        //this.focus();
+    }
+
+    value = parseInt(value)
+    if (value > 10000) {
+        tooltipText = parseInt(value / 10000) + ' 万'
+    }
+    makeToolTips(this, tooltipText, 5000)
+
+}).on('blur', '.letter,.input-letter', function () {
+    makeToolTips(this, this.value.replace(/[a-zA-Z-_]+/g, '') != '' ? '输入的不是纯字母!' : '')
+})
+
+
 function ajaxError(jqXHR, statusText, errorMsg) {
     console.dir(jqXHR)
     console.dir(statusText)
